==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/rendering/RenderState.hpp <==
#ifndef _COM_SUN_STAR_RENDERING_RENDERSTATE_HPP_
#define _COM_SUN_STAR_RENDERING_RENDERSTATE_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_RENDERING_RENDERSTATE_HDL_
#include "com/sun/star/rendering/RenderState.hdl"
#endif

#ifndef _COM_SUN_STAR_RENDERING_XPOLYPOLYGON2D_HPP_
#include "com/sun/star/rendering/XPolyPolygon2D.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_AFFINEMATRIX2D_HPP_
#include "com/sun/star/geometry/AffineMatrix2D.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace rendering {

inline RenderState::RenderState() SAL_THROW( () )
    : AffineTransform()
    , Clip()
    , DeviceColor()
    , CompositeOperation(0)
{
}

inline RenderState::RenderState(const ::com::sun::star::geometry::AffineMatrix2D& AffineTransform_, const ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XPolyPolygon2D >& Clip_, const ::com::sun::star::uno::Sequence< double >& DeviceColor_, const ::sal_Int8& CompositeOperation_) SAL_THROW( () )
    : AffineTransform(AffineTransform_)
    , Clip(Clip_)
    , DeviceColor(DeviceColor_)
    , CompositeOperation(CompositeOperation_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::rendering::RenderState const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.rendering.RenderState");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_RENDERING_RENDERSTATE_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/rendering/RenderState.hpp <==
#ifndef _COM_SUN_STAR_RENDERING_RENDERSTATE_HPP_
#define _COM_SUN_STAR_RENDERING_RENDERSTATE_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_RENDERING_RENDERSTATE_HDL_
#include "com/sun/star/rendering/RenderState.hdl"
#endif

#ifndef _COM_SUN_STAR_RENDERING_XPOLYPOLYGON2D_HPP_
#include "com/sun/star/rendering/XPolyPolygon2D.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_AFFINEMATRIX2D_HPP_
#include "com/sun/star/geometry/AffineMatrix2D.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace rendering {

inline RenderState::RenderState() SAL_THROW( () )
    : AffineTransform()
    , Clip()
    , DeviceColor()
    , CompositeOperation(0)
{
}

inline RenderState::RenderState(const ::com::sun::star::geometry::AffineMatrix2D& AffineTransform_, const ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XPolyPolygon2D >& Clip_, const ::com::sun::star::uno::Sequence< double >& DeviceColor_, const ::sal_Int8& CompositeOperation_) SAL_THROW( () )
    : AffineTransform(AffineTransform_)
    , Clip(Clip_)
    , DeviceColor(DeviceColor_)
    , CompositeOperation(CompositeOperation_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace rendering {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::rendering::RenderState const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.rendering.RenderState");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::rendering::RenderState const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::rendering::RenderState >::get();
}

#endif // _COM_SUN_STAR_RENDERING_RENDERSTATE_HPP_
